@@ -7,3 +7,9 @@ test_that("Import from ODS", {
     expect_true(identical(names(mtcars), names(ods)), label = "ODS import returns correct names")
     expect_true(identical(dim(mtcars), dim(ods)), label = "ODS import returns correct dimensions")
 })
+
+test_that("Export to ODS", {
+    expect_true(export(iris, "iris.ods") %in% dir())
+})
+
+unlink("iris.ods")
